"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatDateToDayAndMonth = exports.isBrowser = exports.isBetweenDates = exports.isFile = exports.groupArticlesByDate = exports.getApiResourceKey = exports.formatDate = exports.getResourceUrl = exports.getFieldValueByFieldLabel = exports.getDisplayDate = exports.getFullSlug = exports.localeMap = void 0;
const enums_1 = require("./enums");
exports.localeMap = {
    en: 'en-US',
    es: 'es-ES',
    nl: 'nl-NL',
    de: 'de-DE',
};
const getFullSlug = (article) => {
    const lastSlashPos = article.url.lastIndexOf('/');
    const secondLastSlashPos = article.url
        .substring(0, lastSlashPos - 1)
        .lastIndexOf('/');
    return article.url.substring(secondLastSlashPos);
};
exports.getFullSlug = getFullSlug;
/**
 * It returns a locale object for the given language, and caches it so that it doesn't have to be
 * created again
 * @param {string} language - The language to use for the date.
 * @returns A function that returns a locale object.
 */
let cachedLocale = null;
function getLocale(language) {
    if (cachedLocale &&
        cachedLocale.resolvedOptions().locale === exports.localeMap[language]) {
        return cachedLocale;
    }
    const newLocale = new Intl.DateTimeFormat(exports.localeMap[language], {
        month: 'long',
        day: '2-digit',
        weekday: 'long',
        year: 'numeric',
        hour: 'numeric',
        minute: 'numeric',
        hourCycle: 'h24',
    });
    cachedLocale = newLocale;
    return newLocale;
}
function getDisplayDate(date, withTime = false, showDayName = false, showTimeOnly = false) {
    if (typeof date === 'string') {
        const language = process.env.NEXT_PUBLIC_LANGUAGE || 'en';
        const locale = getLocale(language);
        const d1 = new Date(date);
        const month = locale.formatToParts(d1)[language === 'en' ? 2 : 4].value;
        const day = locale.formatToParts(d1)[language === 'en' ? 4 : 2].value;
        const weekDay = locale.formatToParts(d1)[0].value;
        const year = locale.formatToParts(d1)[6].value;
        const hour = locale.formatToParts(d1)[8].value;
        const minute = locale.formatToParts(d1)[10].value;
        if (!showTimeOnly) {
            const dayName = showDayName ? `${weekDay}, ` : '';
            return `${dayName}${day} ${month} ${year}${withTime ? ` at ${hour}:${minute}` : ''}`;
        }
        else {
            return `${hour}:${minute}`;
        }
    }
    const { weekDay, day, minute, month, hour, year } = date;
    if (!showTimeOnly) {
        const dayName = showDayName ? `${weekDay}, ` : '';
        return `${dayName}${day} ${month} ${year}${withTime ? ` at ${hour}:${minute}` : ''}`;
    }
    else {
        return `${hour}:${minute}`;
    }
}
exports.getDisplayDate = getDisplayDate;
/**
 * This function is used to return the value of IFieldBlock "lib/models/IFieldBlock" which has
 * label equal to @param label
 *
 * @returns Object
 */
const getFieldValueByFieldLabel = (label, fields) => {
    let filterFn;
    if (fields?.length) {
        if (fields[0].label)
            filterFn = (item) => item?.label === label;
        else
            filterFn = (item) => item.field?.label === label;
    }
    else {
        return false;
    }
    const result = fields.filter(filterFn);
    return result ? result[0]?.value : false;
};
exports.getFieldValueByFieldLabel = getFieldValueByFieldLabel;
/**
 * this function will @returns string
 * the return value is arilative URL for any resourse[artical,tag,collection-item,...]
 */
const getResourceUrl = (resource, resourceType) => {
    let resourceUrl = '';
    if (resourceType === enums_1.RESOURCE.Article) {
        const article = resource;
        resourceUrl = `/${article.primary_tag.slug}/${article.slug}`;
    }
    if (resourceType === enums_1.RESOURCE.Collection) {
        resourceUrl = `/${resource.slug}`;
    }
    if (resourceType === enums_1.RESOURCE.CollectionItem) {
        const collectionItem = resource;
        resourceUrl = `/${collectionItem.collection.slug}/${collectionItem.slug}`;
    }
    if (resourceType === enums_1.RESOURCE.Tag) {
        resourceUrl = `/${resource.slug}`;
    }
    if (resourceType === enums_1.RESOURCE.Forum) {
        resourceUrl = `/forum/${resource.slug}`;
    }
    return resourceUrl;
};
exports.getResourceUrl = getResourceUrl;
const formatDate = (dateStr) => {
    const date = new Date(dateStr);
    return `${date.getDate().toString().padStart(2, '0')}-${(date.getMonth() + 1)
        .toString()
        .padStart(2, '0')}-${date.getFullYear().toString().padStart(2, '0')}`;
};
exports.formatDate = formatDate;
/**
 * ex:collection-item is tag actually
 * @param resource
 * @returns article ,tag, collection, page
 */
const getApiResourceKey = (resource) => {
    return resource === enums_1.RESOURCE.CollectionItem ? enums_1.RESOURCE.Tag : resource;
};
exports.getApiResourceKey = getApiResourceKey;
const groupArticlesByDate = (articles) => {
    const groupedArticlesObj = {};
    articles.reduce((prev, currArticle) => {
        const dateStr = (0, exports.formatDate)(currArticle.published_at);
        if (!groupedArticlesObj[dateStr])
            groupedArticlesObj[dateStr] = [];
        groupedArticlesObj[dateStr].push(currArticle);
        return prev;
    }, groupedArticlesObj);
    const sortedArticlesArr = Object.keys(groupedArticlesObj).map((dateStr) => {
        return groupedArticlesObj[dateStr];
    });
    return sortedArticlesArr;
};
exports.groupArticlesByDate = groupArticlesByDate;
const isFile = (slug) => {
    const regex = /[^\\]*\.(\w+)$/;
    return slug.match(regex) !== null;
};
exports.isFile = isFile;
const isBetweenDates = (startDate, endDate) => {
    const d1 = new Date(startDate);
    const d2 = new Date(endDate);
    const d3 = new Date();
    return d3 > d1 && d3 < d2;
};
exports.isBetweenDates = isBetweenDates;
const isBrowser = () => typeof window !== 'undefined';
exports.isBrowser = isBrowser;
function formatDateToDayAndMonth(dateString) {
    const date = new Date(dateString);
    const formattedDate = new Intl.DateTimeFormat('en', {
        day: '2-digit',
        month: '2-digit',
    }).format(date);
    const [day, month] = formattedDate.split('/');
    return `${month}/${day}`;
}
exports.formatDateToDayAndMonth = formatDateToDayAndMonth;
